@@ -1,7 +1,5 @@
 import renderapi
 import pytest
-import tempfile
-import os
 import logging
 import sys
 import json
@@ -18,7 +16,7 @@ ch.setLevel(logging.DEBUG)
 formatter = logging.Formatter(
     '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 ch.setFormatter(formatter)
-#
+
 logger.addHandler(ch)
 
 
