@@ -7,9 +7,11 @@ Currently only implemented to facilitate Affine and Polynomial2D
 import json
 import logging
 from collections import Iterable
+
 import numpy as np
+
 from .errors import ConversionError, EstimationError, RenderError
-from .utils import NullHandler
+from .utils import NullHandler, encodeBase64, decodeBase64
 
 logger = logging.getLogger(__name__)
 logger.addHandler(NullHandler())
@@ -103,7 +105,7 @@ class TransformList:
                 self.tforms.append(load_transform_json(td))
         return self.tforms
 
-        
+
 def load_transform_json(d, default_type='leaf'):
     """function to get the proper deserialization function
 
@@ -193,7 +195,7 @@ class InterpolatedTransform:
     lambda_ : float
         value in interval [0.,1.] which defines evaluation of the
         linear interpolation between a (at 0) and b (at 1)
-    """
+    """  # noqa: E501
 
     def __init__(self, a=None, b=None, lambda_=None, json=None):
         """Initialize InterpolatedTransform
@@ -773,9 +775,13 @@ class TranslationModel(AffineModel):
 
     def _process_dataString(self, dataString):
         """expected dataString is 'tx ty'"""
-        tx, ty = map(float(dataString.split(' ')))
+        tx, ty = map(float, dataString.split(' '))
         self.B0 = tx
         self.B1 = ty
+        self.M00 = 1
+        self.M10 = 0
+        self.M01 = 0
+        self.M11 = 1
         self.load_M()
 
     @staticmethod
@@ -864,7 +870,7 @@ class RigidModel(AffineModel):
 
     def _process_dataString(self, dataString):
         """expected datastring is 'theta tx ty'"""
-        theta, tx, ty = map(float(dataString.split(' ')))
+        theta, tx, ty = map(float, dataString.split(' '))
         self.M00 = np.cos(theta)
         self.M01 = -np.sin(theta)
         self.M10 = np.sin(theta)
@@ -993,7 +999,7 @@ class SimilarityModel(RigidModel):
 
     def _process_dataString(self, dataString):
         """expected datastring is 's theta tx ty'"""
-        s, theta, tx, ty = map(float(dataString.split(' ')))
+        s, theta, tx, ty = map(float, dataString.split(' '))
         self.M00 = s * np.cos(theta)
         self.M01 = -s * np.sin(theta)
         self.M10 = s * np.sin(theta)
@@ -1384,19 +1390,24 @@ def estimate_dstpts(transformlist, src=None, reference_tforms=None):
     dstpts = src
     for tform in transformlist:
         if isinstance(tform, list):
-            dstpts = estimate_dstpts(tform, dstpts,reference_tforms)
-        elif isinstance(tform,TransformList):
-            dstpts = estimate_dstpts(tform.tforms,dstpts,reference_tforms)
-        elif isinstance(tform,ReferenceTransform):       
+            dstpts = estimate_dstpts(tform, dstpts, reference_tforms)
+        elif isinstance(tform, TransformList):
+            dstpts = estimate_dstpts(tform.tforms, dstpts, reference_tforms)
+        elif isinstance(tform, ReferenceTransform):
             try:
-                tform_deref= next(tf for tf in reference_tforms if tf.transformId==tform.refId)
+                tform_deref = next((tf for tf in reference_tforms
+                                    if tf.transformId == tform.refId))
             except TypeError:
-                raise RenderError("you supplied a set of tranforms that includes a reference transform,\
-                                   but didn't supply a set of reference transforms to enable dereferencing")
+                raise RenderError(
+                    "you supplied a set of tranforms that includes a "
+                    "reference transform, but didn't supply a set of "
+                    "reference transforms to enable dereferencing")
             except StopIteration:
-                raise RenderError("the list of transforms you provided references transorm {} but that transform\
-                                    could not be found in the list of reference transforms".format(tform.refId))
-            dstpts=estimate_dstpts([tform_deref],dstpts,reference_tforms)
+                raise RenderError(
+                    "the list of transforms you provided references "
+                    "transorm {} but that transform could not be found "
+                    "in the list of reference transforms".format(tform.refId))
+            dstpts = estimate_dstpts([tform_deref], dstpts, reference_tforms)
         else:
             dstpts = tform.tform(dstpts)
     return dstpts
@@ -1436,7 +1447,8 @@ class NonLinearCoordinateTransform(Transform):
             if labels is not None:
                 self.labels = labels
             self.transformId = transformId
-            self.className = 'mpicbg.trakem2.transform.NonLinearCoordinateTransform'
+            self.className = (
+                'mpicbg.trakem2.transform.NonLinearCoordinateTransform')
 
     def _process_dataString(self, dataString):
 
@@ -1473,7 +1485,7 @@ class NonLinearCoordinateTransform(Transform):
                 "incorrect number of normVar coefficents "
                 "{} != {}".format(self.normVar.shape[0], self.length))
 
-    def kernelExpand(self, src):
+    def kernelExpand(self, src, normMean=None, normVar=None):
         """creates an expanded representation of the x,y
         src points in a polynomial form
 
@@ -1498,11 +1510,83 @@ class NonLinearCoordinateTransform(Transform):
                     np.power(x, j) * np.power(y, i - j))
                 pidx += 1
 
-        expanded[:, :-1] = ((expanded[:, :-1] - self.normMean[:-1]) /
-                            self.normVar[:-1])
+        if normMean is None:
+            normMean = self.normMean
+        if normVar is None:
+            normVar = self.normVar
+
+        expanded[:, :-1] = ((expanded[:, :-1] - normMean[:-1]) /
+                            normVar[:-1])
         expanded[:, -1] = 100.0
         return expanded
 
+    def fit(self, A, B):
+        """function to fit this transform given the corresponding sets of points A & B
+        Parameters
+        ----------
+        A : numpy.array
+            a Nx2 matrix of source points
+        B : numpy.array
+            a Nx2 matrix of destination points
+
+        Returns
+        -------
+        beta
+            a self.lengthx2 matrix with polynomial factors
+        normMean
+            a self.length vector of expanded means
+        normVar
+            a self.length vector of expanded standard deviations
+        """
+        if not all([A.shape[0] == B.shape[0], A.shape[1] == B.shape[1] == 2]):
+            raise EstimationError(
+                'shape mismatch! A shape: {}, B shape {}'.format(
+                    A.shape, B.shape))
+
+        normMean = np.zeros(self.length).astype('float')
+        normVar = np.ones(self.length).astype('float')
+        src_exp = self.kernelExpand(A, normMean=normMean, normVar=normVar)
+        normMean = src_exp.mean(0)
+        normVar = src_exp.std(0)  # poorly named variable
+        src_exp = self.kernelExpand(A, normMean=normMean, normVar=normVar)
+
+        xcoeff, xresiduals, xrank, xs = np.linalg.lstsq(src_exp, B[:, 0])
+        ycoeff, yresiduals, yrank, ys = np.linalg.lstsq(src_exp, B[:, 1])
+
+        beta = np.zeros((self.length, 2))
+        beta[:, 0] = xcoeff
+        beta[:, 1] = ycoeff
+
+        return beta, normMean, normVar
+
+    def estimate(self, A, B, ndim=None, return_params=True, **kwargs):
+        """method for setting this transformation with the best fit
+        given the corresponding points A,B
+
+        Parameters
+        ----------
+        A : numpy.array
+            a Nx2 matrix of source points
+        B : numpy.array
+            a Nx2 matrix of destination points
+        return_params : boolean
+            whether to return the dataString
+        **kwargs
+            keyword arguments to pass to self.fit
+
+        Returns
+        -------
+        dataString
+        """
+
+        beta, normMean, normVar = self.fit(A, B)
+        self.beta = beta
+        self.normMean = normMean
+        self.normVar = normVar
+
+        if return_params:
+            return self.dataString
+
     def tform(self, src):
         """transform a set of points through this transformation
 
@@ -1542,6 +1626,85 @@ class NonLinearCoordinateTransform(Transform):
             shapestring, betastring, meanstring, varstring, dimstring)
 
 
+class ThinPlateSplineTransform(Transform):
+    """
+    render-python class that can hold a dataString for
+    mpicbg.trakem2.transform.ThinPlateSplineTransform class.
+    Parameters
+    ----------
+    dataString: str or None
+        data string of transformation
+    labels : list of str
+        list of labels to give this transform
+    json: dict or None
+        json compatible dictionary representation of the transformation
+    Returns
+    -------
+    :class:`ThinPlateSplineTransform`
+        a transform instance
+    """
+
+    className = 'mpicbg.trakem2.transform.ThinPlateSplineTransform'
+
+    def __init__(self, dataString=None, json=None, transformId=None,
+                 labels=None):
+        if json is not None:
+            self.from_dict(json)
+        else:
+            if dataString is not None:
+                self._process_dataString(dataString)
+            self.labels = labels
+            self.transformId = transformId
+            self.className = (
+                'mpicbg.trakem2.transform.ThinPlateSplineTransform')
+
+    def _process_dataString(self, dataString):
+        fields = dataString.split(" ")
+
+        self.ndims = int(fields[1])
+        self.nLm = int(fields[2])
+
+        if fields[3] != "null":
+            try:
+                values = decodeBase64(fields[3])
+                self.aMtx = values[0:self.ndims*self.ndims].reshape(
+                                             self.ndims, self.ndims)
+                self.bVec = values[self.ndims*self.ndims:]
+            except ValueError:
+                raise RenderError(
+                    "inconsistent sizes and array lengths, \
+                     in ThinPlateSplineTransform dataString")
+        else:
+            self.aMtx = None
+            self.bVec = None
+
+        try:
+            values = decodeBase64(fields[4])
+            self.srcPts = values[0:self.ndims*self.nLm].reshape(
+                                           self.ndims, self.nLm)
+            self.dMtxDat = values[self.ndims*self.nLm:].reshape(
+                                           self.ndims, self.nLm)
+        except ValueError:
+            raise RenderError(
+                "inconsistent sizes and array lengths, \
+                 in ThinPlateSplineTransform dataString")
+
+    @property
+    def dataString(self):
+        header = 'ThinPlateSplineR2LogR {} {}'.format(self.ndims, self.nLm)
+
+        if self.aMtx is not None:
+            blk1 = np.concatenate((self.aMtx.flatten(), self.bVec))
+            b64_1 = encodeBase64(blk1)
+        else:
+            b64_1 = "null"
+
+        blk2 = np.concatenate((self.srcPts.flatten(), self.dMtxDat.flatten()))
+        b64_2 = encodeBase64(blk2)
+
+        return '{} {} {}'.format(header, b64_1, b64_2)
+
+
 class NonLinearTransform(NonLinearCoordinateTransform):
     className = 'mpicbg.trakem2.transform.nonLinearTransform'
 
@@ -1580,7 +1743,7 @@ def estimate_transformsum(transformlist, src=None, order=2):
             if isinstance(i, Iterable):
                 try:
                     notstring = isinstance(i, basestring)
-                except NameError as e:
+                except NameError:
                     notstring = isinstance(i, str)
                 if notstring:
                     for sub in flatten(i):
