@@ -6,13 +6,55 @@ import rendersettings
 import importlib
 import pytest
 
+EPSILON = 0.0000000001
+
+
 def cross_py23_reload(module):
     try:
         reload(module)
-    except NameError as e:
+    except NameError:
         importlib.reload(module)
 
 
+def test_TransformList_init():
+    tlist = renderapi.transform.TransformList()  # noqa: F841
+
+
+def test_simple_TransformList_init():
+    aff = renderapi.transform.AffineModel()
+    tlist = renderapi.transform.TransformList(tforms=[aff])  # noqa: F841
+
+
+def test_fail_TransformList_init():
+    with pytest.raises(renderapi.errors.RenderError):
+        aff = renderapi.transform.AffineModel()
+        tlist = renderapi.transform.TransformList(tforms=aff)   # noqa: F841
+
+
+def test_fail_loadtransform_json():
+    d = {'type': 'not_a_type',
+         'dataString': 'junkstring',
+         'transformId': 'badtform'}
+    with pytest.raises(renderapi.errors.RenderError):
+        renderapi.transform.load_transform_json(d)
+    with pytest.raises(renderapi.errors.RenderError):
+        renderapi.transform.load_leaf_json(d)
+
+
+def test_load_unknown_tform():
+    d = {'className': 'mpicpg.not_supported_transform',
+         'dataString': 'crazy_parameters'}
+    tform = renderapi.transform.load_transform_json(d)
+    assert(isinstance(tform, renderapi.transform.Transform))
+
+
+def test_fail_bad_tform():
+    d = {'type': 'leaf',
+         'className': 'mpicpg.not_supported_transform'}
+    with pytest.raises(renderapi.errors.RenderError):
+        tform = renderapi.transform.load_transform_json(d)  # noqa: F841
+
+
 def test_affine_rot_90():
     am = renderapi.transform.AffineModel()
     # setup a 90 degree clockwise rotation
@@ -247,6 +289,7 @@ def test_reference_transform():
 
     assert (dict(ref_args) == ref_args.to_dict() == dict(ref_ts) ==
             ref_ts.to_dict() == dict(ref_dd) == ref_dd.to_dict())
+    print(ref_dd)
 
 
 def test_transform_hash_eq():
@@ -367,57 +410,92 @@ def test_estimate_translation_transform():
 
 
 def test_non_linear_transform():
-    lens_tform = renderapi.transform.NonLinearTransform(dataString=\
-                                               ("6 28 535.9261337198133 -0.07156495284083819 "
-                                               "1.5429761616475304 482.5391851962856 -1.3964665434772456 "
-                                               "-6.442573400985017 -2.9852709783360574 4.123111145658342 "
-                                               "-11.540309826482599 5.014980246618293 13.616409494909078 "
-                                               "6.8938038217739255 -2.580163142352532 -5.848702515778433 "
-                                               "11.520166623181623 -0.26414636893418164 17.725654626324285 "
-                                               "-3.6910106603259862 -5.747999298096374 6.850067634843171 "
-                                               "16.792611164648633 7.81339608279572 -1.6748576247746882 "
-                                               "7.294185157592906 -8.213479728551924 -5.181177837004834 "
-                                               "-2.363460931085683 2.9307897710181123 -19.60977878575318 "
-                                               "-5.626357722731385 -3.8857454141075323 -15.21120604177655 "
-                                               "-21.23967741658828 -7.433492911261084 5.986054967656173 "
-                                               "-0.2472470831304605 -4.252500955671167 6.285397956497022 "
-                                               "-10.087631670227893 -2.936382384586807 13.850132289055523 "
-                                               "-1.6230114467674603 -6.137660325940608 12.358797331540874 "
-                                               "15.361852639613971 -7.395509537102164 -3.4680250777444144 "
-                                               "11.543534617091353 2.1153010560743724 -6.1108581863128535 "
-                                               "2.4532196427825284 -1.6047644982741716 5.190795110418094 "
-                                               "0.40139303958456196 11.96302944378589 12.660577579061767 "
-                                               "1196.3041637890071 1266.0596612286872 1719846.5445062846 "
-                                               "1485783.6202875 1838252.7229766874 2.714668570418218E9 "
-                                               "2.106666890772152E9 2.1421214796751451E9 2.8349699962925887E9 "
-                                               "4.528468416208078E12 3.2949497103892886E12 3.0161488655484473E12 "
-                                               "3.2930355498080786E12 4.550261299826646E12 7.824367950003595E15 "
-                                               "5.464560367850104E15 4.686502506566912E15 4.616510470870998E15 "
-                                               "5.276444951800235E15 7.530553575860649E15 1.3844135530148071E19 "
-                                               "9.408014352057864E18 7.7275759384866017E18 7.1369460697416591E18 "
-                                               "7.373674200122966E18 8.7221483757320745E18 1.277368891891578E19 "
-                                               "100.0 537.4423453941299 485.2431449404924 1253541.1543424227 "
-                                               "899439.7598253534 1082433.2436210443 2.5451681382231455E9 "
-                                               "1.814150348079708E9 1.6692374367919033E9 2.1769137889095693E9 "
-                                               "4.992425732284977E12 3.5258872445513765E12 3.074020072484778E12 "
-                                               "3.1163128442286265E12 4.266956980967905E12 9.700243843041522E15 "
-                                               "6.781968704541316E15 5.745611297869626E15 5.443791159762913E15 "
-                                               "5.856309886603154E15 8.280136088463922E15 1.8821205899653665E19 "
-                                               "1.3042150458228838E19 1.0829624014456685E19 9.899910593314652E18 "
-                                               "9.885988268659214E18 1.1051253229808925E19 1.6002173610912907E19 "
-                                               "0.0 2048 2048 "),
-                                               transformId="testing")
+    lens_tform = renderapi.transform.NonLinearTransform(dataString=(
+        "6 28 535.9261337198133 -0.07156495284083819 "
+        "1.5429761616475304 482.5391851962856 -1.3964665434772456 "
+        "-6.442573400985017 -2.9852709783360574 4.123111145658342 "
+        "-11.540309826482599 5.014980246618293 13.616409494909078 "
+        "6.8938038217739255 -2.580163142352532 -5.848702515778433 "
+        "11.520166623181623 -0.26414636893418164 17.725654626324285 "
+        "-3.6910106603259862 -5.747999298096374 6.850067634843171 "
+        "16.792611164648633 7.81339608279572 -1.6748576247746882 "
+        "7.294185157592906 -8.213479728551924 -5.181177837004834 "
+        "-2.363460931085683 2.9307897710181123 -19.60977878575318 "
+        "-5.626357722731385 -3.8857454141075323 -15.21120604177655 "
+        "-21.23967741658828 -7.433492911261084 5.986054967656173 "
+        "-0.2472470831304605 -4.252500955671167 6.285397956497022 "
+        "-10.087631670227893 -2.936382384586807 13.850132289055523 "
+        "-1.6230114467674603 -6.137660325940608 12.358797331540874 "
+        "15.361852639613971 -7.395509537102164 -3.4680250777444144 "
+        "11.543534617091353 2.1153010560743724 -6.1108581863128535 "
+        "2.4532196427825284 -1.6047644982741716 5.190795110418094 "
+        "0.40139303958456196 11.96302944378589 12.660577579061767 "
+        "1196.3041637890071 1266.0596612286872 1719846.5445062846 "
+        "1485783.6202875 1838252.7229766874 2.714668570418218E9 "
+        "2.106666890772152E9 2.1421214796751451E9 2.8349699962925887E9 "
+        "4.528468416208078E12 3.2949497103892886E12 3.0161488655484473E12 "
+        "3.2930355498080786E12 4.550261299826646E12 7.824367950003595E15 "
+        "5.464560367850104E15 4.686502506566912E15 4.616510470870998E15 "
+        "5.276444951800235E15 7.530553575860649E15 1.3844135530148071E19 "
+        "9.408014352057864E18 7.7275759384866017E18 7.1369460697416591E18 "
+        "7.373674200122966E18 8.7221483757320745E18 1.277368891891578E19 "
+        "100.0 537.4423453941299 485.2431449404924 1253541.1543424227 "
+        "899439.7598253534 1082433.2436210443 2.5451681382231455E9 "
+        "1.814150348079708E9 1.6692374367919033E9 2.1769137889095693E9 "
+        "4.992425732284977E12 3.5258872445513765E12 3.074020072484778E12 "
+        "3.1163128442286265E12 4.266956980967905E12 9.700243843041522E15 "
+        "6.781968704541316E15 5.745611297869626E15 5.443791159762913E15 "
+        "5.856309886603154E15 8.280136088463922E15 1.8821205899653665E19 "
+        "1.3042150458228838E19 1.0829624014456685E19 9.899910593314652E18 "
+        "9.885988268659214E18 1.1051253229808925E19 1.6002173610912907E19 "
+        "0.0 2048 2048 "), transformId="testing")
 
-    ticks = np.arange(0,2048,64,np.float)
-    xx,yy = np.meshgrid(ticks,ticks)
+    ticks = np.arange(0, 2048, 64, np.float)
+    xx, yy = np.meshgrid(ticks, ticks)
     x = np.ravel(xx).T
     y = np.ravel(yy).T
-    xy = np.vstack((x,y)).T
+    xy = np.vstack((x, y)).T
 
-    xyp=lens_tform.tform(xy)
+    xyp = lens_tform.tform(xy)
     dv = xyp-xy
-    mean_disp= np.mean(np.sqrt(np.sum(dv**2,axis=1)))
-    assert((mean_disp-0.7570507)<.01)
+    mean_disp = np.mean(np.sqrt(np.sum(dv**2, axis=1)))
+    assert((mean_disp-0.7570507) < .01)
+
+
+def test_estimate_non_linear_transform():
+    dataString = (
+            "5 21 1134.6315 27.041916 49.84044 1069.9268 8.754167 "
+            "-8.966886 -67.81902 -26.337778 -42.44015 47.329388 "
+            "-57.457996 -19.826283 12.059551 16.236008 25.214308 "
+            "-6.14843 13.517356 -69.09145 59.978294 9.0963745 2.8096974 "
+            "17.50649 1.8950082 -16.095743 -6.6861115 5.4056945 1.330886 "
+            "67.93751 -21.105675 -1.9647278 -2.1779869 -8.596665 "
+            "0.25304613 0.07506427 -2.4152899 10.851463 5.036614 "
+            "-8.608638 -2.1753247 -22.031227 18.718458 20.106474 "
+            "1871.7964 2010.6288 4716919.0 3762185.0 5205234.5 "
+            "13463128000.0 950763500.0 9750733000.0 14992724000.0 "
+            "41204630000000.0 27199392000000.0 24678496000000.0 "
+            "28117224000000.0 45919358000000.0 1.3180739E+17 "
+            "8.3419896E+16 7.0674915E+16 7.122505E+16 8.621747E+16 "
+            "1.4640968E+17 100.0 1101.5017 1078.2463 4353785.0 3244154.8 "
+            "4338782.5 15909609000.0 11250277000.0 11111349000.0 "
+            "15978368000.0 57421630000000.0 39513703000000.0 "
+            "36268440000000.0 38755805000000.0 57893900000000.0 "
+            "2.0705793E+17 1.4025713E+17 1.2428827E+17 1.23013825E+17 "
+            "1.3686534E+17 2.0921157E+17 0.0 3840 3840 ")
+
+    n = 500
+    x = np.linspace(0, 3840, n)
+    xp, yp = np.meshgrid(x, x)
+    src = np.transpose(np.vstack((xp.flatten(), yp.flatten())))
+
+    tf = renderapi.transform.NonLinearCoordinateTransform(
+            dataString=dataString)
+    dst = tf.tform(src)
+    tf.estimate(src, dst)
+    fdst = tf.tform(src)
+
+    assert(np.abs(fdst-dst).max() < 1e-5)
 
 
 @pytest.mark.parametrize("transform_class,transform_json", [
@@ -457,29 +535,105 @@ def test_load_json_transforms(transform_class, transform_json):
     assert (tform.className == tform_d['className'] ==
             transform_json['className'])
 
+
 @pytest.fixture(scope='module')
 def referenced_tilespecs_and_transforms():
-    with open(rendersettings.REFERENCE_TRANSFORM_TILESPECS,'r') as fp:
+    with open(rendersettings.REFERENCE_TRANSFORM_TILESPECS, 'r') as fp:
         ds = json.load(fp)
         tilespecs = [renderapi.tilespec.TileSpec(json=d) for d in ds]
 
-    with open(rendersettings.REFERENCE_TRANSFORM_SPECS,'r') as fp:
+    with open(rendersettings.REFERENCE_TRANSFORM_SPECS, 'r') as fp:
         ds = json.load(fp)
         transforms = [renderapi.transform.load_transform_json(tf) for tf in ds]
-    return tilespecs,transforms
+    return tilespecs, transforms
+
 
 def test_estimate_dstpoints_reference(referenced_tilespecs_and_transforms):
-    tilespecs,transforms = referenced_tilespecs_and_transforms
+    tilespecs, transforms = referenced_tilespecs_and_transforms
 
-    ticks = np.arange(0,2048,64,np.float)
-    xx,yy = np.meshgrid(ticks,ticks)
+    ticks = np.arange(0, 2048, 64, np.float)
+    xx, yy = np.meshgrid(ticks, ticks)
     x = np.ravel(xx).T
     y = np.ravel(yy).T
-    xy = np.vstack((x,y)).T
+    xy = np.vstack((x, y)).T
 
-    xyt=renderapi.transform.estimate_dstpts(tilespecs[0].tforms,xy,transforms)
-    assert(xy.shape==xyt.shape)
+    xyt = renderapi.transform.estimate_dstpts(
+        tilespecs[0].tforms, xy, transforms)
+    assert(xy.shape == xyt.shape)
     with pytest.raises(renderapi.errors.RenderError):
-        renderapi.transform.estimate_dstpts(tilespecs[0].tforms,xy)
+        renderapi.transform.estimate_dstpts(tilespecs[0].tforms, xy)
     with pytest.raises(renderapi.errors.RenderError):
-        renderapi.transform.estimate_dstpts(tilespecs[0].tforms,xy,[transforms[2]])
+        renderapi.transform.estimate_dstpts(
+            tilespecs[0].tforms, xy, [transforms[2]])
+
+
+def test_fail_convert_points():
+    points_in = np.array([[0, 0], [0, 1], [1, 0], [1, 1]], np.float)
+    with pytest.raises(renderapi.errors.ConversionError):
+        renderapi.transform.AffineModel.convert_to_point_vector(points_in.T)
+
+
+def test_translation_transform_init():
+    d = {'type': 'leaf',
+         'className': 'mpicbg.trakem2.transform.TranslationModel2D',
+         'dataString': '10 0'}
+    tform = renderapi.transform.load_transform_json(d)
+    assert(isinstance(tform, renderapi.transform.TranslationModel))
+    assert(tform.M[0, 2] == 10)
+
+
+def test_rigid_init():
+    d = {'type': 'leaf',
+         'className': 'mpicbg.trakem2.transform.RigidModel2D',
+         'dataString': '{} 10 5'.format(np.pi/2)}
+    tform = renderapi.transform.load_transform_json(d)
+    assert(isinstance(tform, renderapi.transform.RigidModel))
+    assert(tform.M[0, 2] == 10)
+    assert(tform.M[0, 0] < EPSILON)
+
+
+def test_similarity_init():
+    d = {'type': 'leaf',
+         'className': 'mpicbg.trakem2.transform.SimilarityModel2D',
+         'dataString': '2.0 0.0 10 5'}
+    tform = renderapi.transform.load_transform_json(d)
+    assert(isinstance(tform, renderapi.transform.SimilarityModel))
+    assert(np.abs(tform.M[0, 0]-2) < EPSILON)
+    assert(tform.M[0, 2] == 10)
+
+
+def test_thinplatespline():
+    j = json.load(open(rendersettings.TEST_THINPLATESPLINE_FILE, 'r'))
+    t = renderapi.transform.ThinPlateSplineTransform(
+            dataString=j['dataString'])
+    assert (j['dataString'] == t.dataString)
+    t.aMtx = np.zeros(4)
+    t.bVec = np.zeros(2)
+    t2 = renderapi.transform.ThinPlateSplineTransform(
+            dataString=t.dataString)
+    assert (t == t2)
+    # test incorrect lengths
+    with pytest.raises(renderapi.errors.RenderError):
+        s = t2.dataString.split(' ')
+        s[1] = str(int(s[1])+1)
+        t3 = renderapi.transform.ThinPlateSplineTransform(
+                dataString=" ".join(s))
+    with pytest.raises(renderapi.errors.RenderError):
+        s = t2.dataString.split(' ')
+        s[2] = str(int(s[2])-4)
+        t3 = renderapi.transform.ThinPlateSplineTransform(
+                dataString=" ".join(s))
+
+
+def test_encode64():
+    # case for Stephan's '@' character
+    s = '@QAkh+fAbhm6/8AAAAAAAAA=='
+    x = renderapi.utils.decodeBase64(s)
+    assert(x.size == 2)
+    assert(x[0] == 3.14159)
+    assert(x[1] == -1.0)
+    # all other
+    x = np.array([1.0, 3.0, 3.14159, -4.0, 10.0])
+    s = renderapi.utils.encodeBase64(x)
+    y = renderapi.utils.decodeBase64(s)
+    assert(np.all(x == y))
